==> igniteui-webcomponents-inputs-4.6.0.tgz: package/esm2015/lib/XPopupBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { XComponentBridge } from "./XComponentBridge";
import { INativeUIPopupBridge_$type } from "igniteui-webcomponents-core";
import { List$1 } from "igniteui-webcomponents-core";
import { NativeUIComponent } from "igniteui-webcomponents-core";
import { runOn, delegateCombine, delegateRemove, enumGetBox, typeGetValue, EnumUtil, markType } from "igniteui-webcomponents-core";
import { NativeUIPopupOpenedEventArgs } from "igniteui-webcomponents-core";
import { NativeUIPopupClosedEventArgs } from "igniteui-webcomponents-core";
import { NativeUIMouseEventArgs } from "igniteui-webcomponents-core";
import { NativeUIFocusEventArgs } from "igniteui-webcomponents-core";
import { NativeUIPopupAnimationType_$type } from "igniteui-webcomponents-core";
import { NativeUIPopupPointerPosition_$type } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
export let XPopupBridge = /*@__PURE__*/ (() => {
    class XPopupBridge extends XComponentBridge {
        constructor(a) {
            super(a);
            this.ai = null;
            this.ad = null;
            this.ag = null;
            this.ah = null;
            this.ae = null;
            this.af = null;
            this.ab = null;
            this.aa = null;
            this.y = null;
            this.z = null;
            this.w = null;
            this.x = null;
            this.ac = null;
            this.ac = new List$1(NativeUIComponent.$, 0);
        }
        contains(a, b) {
            let c = this.t;
            return c.contains(b);
        }
        addHandler(a, b, c, d) {
            let e = a;
            switch (c) {
                case 5:
                    e.onPopup = delegateCombine(e.onPopup, runOn(this, this.ao));
                    this.ab = d;
                    this.ai = b;
                    break;
                case 6:
                    e.onClosed = delegateCombine(e.onClosed, runOn(this, this.aj));
                    this.aa = d;
                    this.ad = b;
                    break;
                case 7:
                    e.popupMouseEnter = delegateCombine(e.popupMouseEnter, runOn(this, this.am));
                    this.y = d;
                    this.ag = b;
                    break;
                case 8:
                    e.popupMouseLeave = delegateCombine(e.popupMouseLeave, runOn(this, this.an));
                    this.z = d;
                    this.ah = b;
                    break;
                case 12:
                    e.popupGotFocus = delegateCombine(e.popupGotFocus, runOn(this, this.ak));
                    this.w = d;
                    this.ae = b;
                    break;
                case 13:
                    e.popupLostFocus = delegateCombine(e.popupLostFocus, runOn(this, this.al));
                    this.x = d;
                    this.af = b;
                    break;
            }
        }
        removeHandler(a, b, c, d) {
            let e = a;
            switch (c) {
                case 5:
                    e.onPopup = delegateRemove(e.onPopup, runOn(this, this.ao));
                    this.ab = null;
                    this.ai = null;
                    break;
                case 6:
                    e.onClosed = delegateRemove(e.onClosed, runOn(this, this.aj));
                    this.aa = null;
                    this.ad = null;
                    break;
                case 7:
                    e.popupMouseEnter = delegateRemove(e.popupMouseEnter, runOn(this, this.am));
                    this.y = null;
                    this.ag = null;
                    break;
                case 8:
                    e.popupMouseLeave = delegateRemove(e.popupMouseLeave, runOn(this, this.an));
                    this.z = null;
                    this.ah = null;
                    break;
                case 12:
                    e.popupGotFocus = delegateRemove(e.popupGotFocus, runOn(this, this.ak));
                    this.w = null;
                    this.ae = null;
                    break;
                case 13:
                    e.popupLostFocus = delegateRemove(e.popupLostFocus, runOn(this, this.al));
                    this.x = null;
                    this.af = null;
                    break;
            }
        }
        ao(a, b) {
            if (this.ab != null) {
                this.ab(this.ai, new NativeUIPopupOpenedEventArgs());
            }
        }
        aj(a, b) {
            if (this.aa != null) {
                this.aa(this.ad, new NativeUIPopupClosedEventArgs());
            }
        }
        am(a, b) {
            if (this.y != null) {
                this.y(this.ag, new NativeUIMouseEventArgs());
            }
        }
        an(a, b) {
            if (this.z != null) {
                this.z(this.ah, new NativeUIMouseEventArgs());
            }
        }
        ak(a, b) {
            if (this.w != null) {
                this.w(this.ae, new NativeUIFocusEventArgs());
            }
        }
        al(a, b) {
            if (this.x != null) {
                this.x(this.af, ((() => {
                    let $ret = new NativeUIFocusEventArgs();
                    $ret.a = b.a;
                    return $ret;
                })()));
            }
        }
        getValue(a, b) {
            let c = a;
            switch (b) {
                case 22: return c.aw;
                case 25: return c.al;
                case 26: return c.a8;
                case 17: return c.a0;
                case 23: return c.cw;
                case 35: switch (c.p) {
                    case 1: return enumGetBox(NativeUIPopupAnimationType_$type, 1);
                    default: return enumGetBox(NativeUIPopupAnimationType_$type, 0);
                }
                case 36: return c.as;
                case 37: return c.ar;
                case 40: return c.ba;
                case 41: return c.at;
                case 43: switch (c.u) {
                    case 1: return enumGetBox(NativeUIPopupPointerPosition_$type, 1);
                    default: return enumGetBox(NativeUIPopupPointerPosition_$type, 2);
                }
                case 42: return c.c0;
                case 39: return c.an;
                case 61: return c.a3;
            }
            return super.getValue(a, b);
        }
        setValue(a, b, c) {
            let d = a;
            switch (b) {
                case 25:
                    d.al = c;
                    break;
                case 26:
                    d.a8 = typeGetValue(c);
                    break;
                case 17:
                    d.a0 = c;
                    break;
                case 23:
                    d.cw = c;
                    break;
                case 35:
                    switch (EnumUtil.getEnumValue(NativeUIPopupAnimationType_$type, c)) {
                        case 1:
                            d.p = 1;
                            break;
                        default:
                            d.p = 0;
                            break;
                    }
                    break;
                case 36:
                    d.as = c;
                    break;
                case 37:
                    d.ar = c;
                    break;
                case 40:
                    d.ba = typeGetValue(c);
                    break;
                case 41:
                    d.at = c;
                    break;
                case 42:
                    d.c0 = c;
                    break;
                case 43:
                    switch (EnumUtil.getEnumValue(NativeUIPopupPointerPosition_$type, c)) {
                        case 1:
                            d.u = 1;
                            break;
                        case 2:
                            d.u = 2;
                            break;
                    }
                    break;
                case 39:
                    d.an = c;
                    break;
                case 61:
                    d.a3 = c;
                    break;
            }
            super.setValue(a, b, c);
        }
        showRelativeToExclusionRect(a, b, c, d) {
            a.showRelativeToExclusionRect(b, this.v(c), this.u(d));
        }
        close(a) {
            a.b3();
        }
        notifyContentSizeChanged(a) {
            a.b6();
        }
        notifyExclusionRectChanged(a, b) {
            a.b7(b);
        }
        v(a) {
            switch (a) {
                case 0: return 0;
                case 1: return 1;
                case 2: return 2;
                case 3: return 3;
                case 4: return 4;
                default: return 0;
            }
        }
        u(a) {
            switch (a) {
                case 0: return 0;
                case 2: return 2;
                case 1: return 1;
                case 3: return 3;
                default: return 0;
            }
        }
        addChild(a, b) {
            this.ac.add(b);
            let c = a;
            c.appendPopupContent(b.al);
        }
        insertChild(a, b, c) {
            this.ac.add(c);
            let d = a;
            d.appendPopupContent(c.al);
        }
        getChildAt(a, b) {
            return this.ac._inner[b];
        }
        getChildrenCount(a) {
            return this.ac.count;
        }
        removeChild(a, b) {
            let c = a;
            c.removePopupContent(b.al);
            this.ac.remove(b);
        }
        removeChildAt(a, b) {
            let c = a;
            c.removePopupContent(this.ac._inner[b].al);
            this.ac.removeAt(b);
        }
    }
    XPopupBridge.$t = /*@__PURE__*/ markType(XPopupBridge, 'XPopupBridge', XComponentBridge.$, [INativeUIPopupBridge_$type]);
    return XPopupBridge;
})();

==> igniteui-webcomponents-inputs-5.0.0.tgz: package/esm2015/lib/XPopupBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { XComponentBridge } from "./XComponentBridge";
import { INativeUIPopupBridge_$type } from "igniteui-webcomponents-core";
import { List$1 } from "igniteui-webcomponents-core";
import { NativeUIComponent } from "igniteui-webcomponents-core";
import { runOn, delegateCombine, delegateRemove, enumGetBox, typeGetValue, EnumUtil, markType } from "igniteui-webcomponents-core";
import { NativeUIPopupOpenedEventArgs } from "igniteui-webcomponents-core";
import { NativeUIPopupClosedEventArgs } from "igniteui-webcomponents-core";
import { NativeUIMouseEventArgs } from "igniteui-webcomponents-core";
import { NativeUIFocusEventArgs } from "igniteui-webcomponents-core";
import { NativeUIPopupAnimationType_$type } from "igniteui-webcomponents-core";
import { NativeUIPopupPointerPosition_$type } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
export let XPopupBridge = /*@__PURE__*/ (() => {
    class XPopupBridge extends XComponentBridge {
        constructor(a) {
            super(a);
            this.ai = null;
            this.ad = null;
            this.ag = null;
            this.ah = null;
            this.ae = null;
            this.af = null;
            this.ab = null;
            this.aa = null;
            this.y = null;
            this.z = null;
            this.w = null;
            this.x = null;
            this.ac = null;
            this.ac = new List$1(NativeUIComponent.$, 0);
        }
        contains(a, b) {
            let c = this.t;
            return c.contains(b);
        }
        addHandler(a, b, c, d) {
            let e = a;
            switch (c) {
                case 5:
                    e.onPopup = delegateCombine(e.onPopup, runOn(this, this.ao));
                    this.ab = d;
                    this.ai = b;
                    break;
                case 6:
                    e.onClosed = delegateCombine(e.onClosed, runOn(this, this.aj));
                    this.aa = d;
                    this.ad = b;
                    break;
                case 7:
                    e.popupMouseEnter = delegateCombine(e.popupMouseEnter, runOn(this, this.am));
                    this.y = d;
                    this.ag = b;
                    break;
                case 8:
                    e.popupMouseLeave = delegateCombine(e.popupMouseLeave, runOn(this, this.an));
                    this.z = d;
                    this.ah = b;
                    break;
                case 13:
                    e.popupGotFocus = delegateCombine(e.popupGotFocus, runOn(this, this.ak));
                    this.w = d;
                    this.ae = b;
                    break;
                case 14:
                    e.popupLostFocus = delegateCombine(e.popupLostFocus, runOn(this, this.al));
                    this.x = d;
                    this.af = b;
                    break;
            }
        }
        removeHandler(a, b, c, d) {
            let e = a;
            switch (c) {
                case 5:
                    e.onPopup = delegateRemove(e.onPopup, runOn(this, this.ao));
                    this.ab = null;
                    this.ai = null;
                    break;
                case 6:
                    e.onClosed = delegateRemove(e.onClosed, runOn(this, this.aj));
                    this.aa = null;
                    this.ad = null;
                    break;
                case 7:
                    e.popupMouseEnter = delegateRemove(e.popupMouseEnter, runOn(this, this.am));
                    this.y = null;
                    this.ag = null;
                    break;
                case 8:
                    e.popupMouseLeave = delegateRemove(e.popupMouseLeave, runOn(this, this.an));
                    this.z = null;
                    this.ah = null;
                    break;
                case 13:
                    e.popupGotFocus = delegateRemove(e.popupGotFocus, runOn(this, this.ak));
                    this.w = null;
                    this.ae = null;
                    break;
                case 14:
                    e.popupLostFocus = delegateRemove(e.popupLostFocus, runOn(this, this.al));
                    this.x = null;
                    this.af = null;
                    break;
            }
        }
        ao(a, b) {
            if (this.ab != null) {
                this.ab(this.ai, new NativeUIPopupOpenedEventArgs());
            }
        }
        aj(a, b) {
            if (this.aa != null) {
                this.aa(this.ad, new NativeUIPopupClosedEventArgs());
            }
        }
        am(a, b) {
            if (this.y != null) {
                this.y(this.ag, new NativeUIMouseEventArgs());
            }
        }
        an(a, b) {
            if (this.z != null) {
                this.z(this.ah, new NativeUIMouseEventArgs());
            }
        }
        ak(a, b) {
            if (this.w != null) {
                this.w(this.ae, new NativeUIFocusEventArgs());
            }
        }
        al(a, b) {
            if (this.x != null) {
                this.x(this.af, ((() => {
                    let $ret = new NativeUIFocusEventArgs();
                    $ret.a = b.a;
                    return $ret;
                })()));
            }
        }
        getValue(a, b) {
            let c = a;
            switch (b) {
                case 22: return c.aw;
                case 25: return c.al;
                case 26: return c.a8;
                case 17: return c.a0;
                case 23: return c.cy;
                case 35: switch (c.p) {
                    case 1: return enumGetBox(NativeUIPopupAnimationType_$type, 1);
                    default: return enumGetBox(NativeUIPopupAnimationType_$type, 0);
                }
                case 36: return c.as;
                case 37: return c.ar;
                case 40: return c.ba;
                case 41: return c.at;
                case 43: switch (c.u) {
                    case 1: return enumGetBox(NativeUIPopupPointerPosition_$type, 1);
                    default: return enumGetBox(NativeUIPopupPointerPosition_$type, 2);
                }
                case 42: return c.c2;
                case 39: return c.an;
                case 61: return c.a3;
            }
            return super.getValue(a, b);
        }
        setValue(a, b, c) {
            let d = a;
            switch (b) {
                case 25:
                    d.al = c;
                    break;
                case 26:
                    d.a8 = typeGetValue(c);
                    break;
                case 17:
                    d.a0 = c;
                    break;
                case 23:
                    d.cy = c;
                    break;
                case 35:
                    switch (EnumUtil.getEnumValue(NativeUIPopupAnimationType_$type, c)) {
                        case 1:
                            d.p = 1;
                            break;
                        default:
                            d.p = 0;
                            break;
                    }
                    break;
                case 36:
                    d.as = c;
                    break;
                case 37:
                    d.ar = c;
                    break;
                case 40:
                    d.ba = typeGetValue(c);
                    break;
                case 41:
                    d.at = c;
                    break;
                case 42:
                    d.c2 = c;
                    break;
                case 43:
                    switch (EnumUtil.getEnumValue(NativeUIPopupPointerPosition_$type, c)) {
                        case 1:
                            d.u = 1;
                            break;
                        case 2:
                            d.u = 2;
                            break;
                    }
                    break;
                case 39:
                    d.an = c;
                    break;
                case 61:
                    d.a3 = c;
                    break;
            }
            super.setValue(a, b, c);
        }
        showRelativeToExclusionRect(a, b, c, d) {
            a.showRelativeToExclusionRect(b, this.v(c), this.u(d));
        }
        close(a) {
            a.b5();
        }
        notifyContentSizeChanged(a) {
            a.b8();
        }
        notifyExclusionRectChanged(a, b) {
            a.b9(b);
        }
        v(a) {
            switch (a) {
                case 0: return 0;
                case 1: return 1;
                case 2: return 2;
                case 3: return 3;
                case 4: return 4;
                default: return 0;
            }
        }
        u(a) {
            switch (a) {
                case 0: return 0;
                case 2: return 2;
                case 1: return 1;
                case 3: return 3;
                default: return 0;
            }
        }
        exportVisualData(a) {
            return a.au();
        }
        addChild(a, b) {
            this.ac.add(b);
            let c = a;
            c.appendPopupContent(b.an);
        }
        insertChild(a, b, c) {
            this.ac.add(c);
            let d = a;
            d.appendPopupContent(c.an);
        }
        getChildAt(a, b) {
            return this.ac._inner[b];
        }
        getChildrenCount(a) {
            return this.ac.count;
        }
        removeChild(a, b) {
            let c = a;
            c.removePopupContent(b.an);
            this.ac.remove(b);
        }
        removeChildAt(a, b) {
            let c = a;
            c.removePopupContent(this.ac._inner[b].an);
            this.ac.removeAt(b);
        }
    }
    XPopupBridge.$t = /*@__PURE__*/ markType(XPopupBridge, 'XPopupBridge', XComponentBridge.$, [INativeUIPopupBridge_$type]);
    return XPopupBridge;
})();
